==> v1.0.3.zip: portfolio/web/src/components/Tag/Tag/Tag.tsx <==
import type {
  DeleteTagMutation,
  DeleteTagMutationVariables,
  FindTagById,
} from 'types/graphql'

import { Link, routes, navigate } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import {} from 'src/lib/formatters'
import { calculateLuminance } from 'src/lib/color'

const DELETE_TAG_MUTATION: TypedDocumentNode<
  DeleteTagMutation,
  DeleteTagMutationVariables
> = gql`
  mutation DeleteTagMutation($id: Int!) {
    deleteTag(id: $id) {
      id
    }
  }
`

interface Props {
  tag: NonNullable<FindTagById['tag']>
}

const Tag = ({ tag }: Props) => {
  const [deleteTag] = useMutation(DELETE_TAG_MUTATION, {
    onCompleted: () => {
      toast.success('Tag deleted')
      navigate(routes.tags())
    },
    onError: (error) => toast.error(error.message),
  })

  const onDeleteClick = (id: DeleteTagMutationVariables['id']) => {
    if (confirm('Are you sure you want to delete tag ' + id + '?'))
      deleteTag({ variables: { id } })
  }

  return (
    <div className="flex w-full justify-center">
      <div className="w-80">
        <div className="overflow-hidden overflow-x-auto rounded-xl bg-base-100">
          <table className="table">
            <thead className="bg-base-200 font-syne">
              <th className="w-0">
                Tag {tag.id}: {tag.tag}
              </th>
              <th>&nbsp;</th>
            </thead>
            <tbody>
              <tr>
                <th>ID</th>
                <td>{tag.id}</td>
              </tr>
              <tr>
                <th>Tag</th>
                <td>{tag.tag}</td>
              </tr>
              <tr>
                <th>Color</th>
                <td>
                  <div
                    className="badge whitespace-nowrap"
                    style={{
                      backgroundColor: tag.color,
                      color:
                        calculateLuminance(tag.color) > 0.5 ? 'black' : 'white',
                    }}
                  >
                    {tag.color}
                  </div>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
        <nav className="my-2 flex justify-center space-x-2">
          <Link
            to={routes.editTag({ id: tag.id })}
            title={'Edit tag ' + tag.id}
            className="btn btn-primary btn-sm uppercase"
          >
            Edit
          </Link>
          <button
            type="button"
            title={'Delete tag ' + tag.id}
            className="btn btn-error btn-sm uppercase"
            onClick={() => onDeleteClick(tag.id)}
          >
            Delete
          </button>
        </nav>
      </div>
    </div>
  )
}

export default Tag

==> v1.1.6-1.zip: portfolio/web/src/components/Tag/Tag/Tag.tsx <==
import type {
  DeleteTagMutation,
  DeleteTagMutationVariables,
  FindTagById,
} from 'types/graphql'

import { Link, routes, navigate } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import {} from 'src/lib/formatters'
import { calculateLuminance } from 'src/lib/color'

const DELETE_TAG_MUTATION: TypedDocumentNode<
  DeleteTagMutation,
  DeleteTagMutationVariables
> = gql`
  mutation DeleteTagMutation($id: Int!) {
    deleteTag(id: $id) {
      id
    }
  }
`

interface Props {
  tag: NonNullable<FindTagById['tag']>
}

const Tag = ({ tag }: Props) => {
  const [deleteTag] = useMutation(DELETE_TAG_MUTATION, {
    onCompleted: () => {
      toast.success('Tag deleted')
      navigate(routes.tags())
    },
    onError: (error) => toast.error(error.message),
  })

  const onDeleteClick = (id: DeleteTagMutationVariables['id']) => {
    if (confirm('Are you sure you want to delete tag ' + id + '?'))
      deleteTag({ variables: { id } })
  }

  return (
    <div className="flex mx-auto max-w-80 sm:max-w-sm md:max-w-md lg:max-w-lg xl:max-w-xl 2xl:max-w-2xl justify-center">
      <div className="w-full">
        <div className="overflow-hidden overflow-x-auto rounded-xl bg-base-100">
          <table className="table">
            <thead className="bg-base-200 font-syne">
              <th className="w-0">
                Tag {tag.id}: {tag.tag}
              </th>
              <th>&nbsp;</th>
            </thead>
            <tbody>
              <tr>
                <th className="text-right">ID</th>
                <td>{tag.id}</td>
              </tr>
              <tr>
                <th className="text-right">Tag</th>
                <td>{tag.tag}</td>
              </tr>
              <tr>
                <th className="text-right">Color</th>
                <td>
                  <div
                    className="badge whitespace-nowrap"
                    style={{
                      backgroundColor: tag.color,
                      color:
                        calculateLuminance(tag.color) > 0.5 ? 'black' : 'white',
                    }}
                  >
                    {tag.color}
                  </div>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
        <nav className="my-2 flex justify-center space-x-2">
          <Link
            to={routes.editTag({ id: tag.id })}
            title={'Edit tag ' + tag.id}
            className="btn btn-primary btn-sm uppercase"
          >
            Edit
          </Link>
          <button
            type="button"
            title={'Delete tag ' + tag.id}
            className="btn btn-error btn-sm uppercase"
            onClick={() => onDeleteClick(tag.id)}
          >
            Delete
          </button>
        </nav>
      </div>
    </div>
  )
}

export default Tag
